#!/usr/bin/env python2
# Copyright 1999-2023. Plesk International GmbH. All rights reserved.

"""Update password for administrator of maillist

Usage:	%(PROGRAM)s [options] listname encrypted_password

   --help
    -h
        Print this help message and exit.
"""

import string
import sys
import os

prefix = '/usr/lib/mailman/bin'
sys.path.insert(0, prefix)

import paths                    # noqa E402,F401 (required for 'Mailman' module access below)

from Mailman import mm_cfg      # noqa E402,F401
from Mailman import MailList    # noqa E402
from Mailman import Errors      # noqa E402


PROGRAM = sys.argv[0]


def usage(code, msg=''):
    print (__doc__)
    if msg:
        print msg
    sys.exit(code)


def main():
    # Throw away the first (program) argument
    args = sys.argv[1:]
    if not args:
        usage(0)
    while 1:
        try:
            opt = args.pop(0)
        except IndexError:
            usage(1)
        if opt in ('-h', '--help'):
            usage(0)
        else:
            # No more options left, push the last one back on the list
            args.insert(0, opt)
            break
    if len(args) < 2:
        password = os.environ.get("PSA_CRYPTED_PASSWORD")
    elif len(args) == 2:
        password = args[1]
    else:
        usage(1)

    listname = string.lower(args[0])
    try:
        mlist = MailList.MailList(listname, lock=1)
        mlist.password = password
        mlist.Save()
        mlist.Unlock()
    except Errors.MMListError:
        print 'No such list: ', listname
        sys.exit(1)


if __name__ == '__main__':
    main()
